@@ -59,11 +59,13 @@ def get_cmdclasses(
     build_py_base = cmds.get("build_py", build_py)
 
     class VersioningitBuildPy(build_py_base):  # type: ignore[valid-type,misc]
+        editable_mode: bool = False
+
         def run(self) -> None:
             super().run()
             init_logging()
             template_fields = get_template_fields_from_distribution(self.distribution)
-            if template_fields is not None:
+            if not self.editable_mode and template_fields is not None:
                 PROJECT_ROOT = Path().resolve()
                 log.debug("Running onbuild step; cwd=%s", PROJECT_ROOT)
                 run_onbuild(
